Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(612)

Unified Diff: scripts/master/pubsub_json_status_push.py

Issue 2422503002: Pubsub: Restrict full pending builds states to 25 per builder (from 75) (Closed)
Patch Set: Fixed bad rebase Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: scripts/master/pubsub_json_status_push.py
diff --git a/scripts/master/pubsub_json_status_push.py b/scripts/master/pubsub_json_status_push.py
index 8df82064e8b7a81fb1a9bd728faebfc171f967d0..06b5b941323e5cc268d17df90242216166cf8c2c 100644
--- a/scripts/master/pubsub_json_status_push.py
+++ b/scripts/master/pubsub_json_status_push.py
@@ -372,10 +372,10 @@ class StatusPush(StatusReceiverMultiService):
# This requires a deferred call since the data is queried from
# the postgres DB (sigh).
pending = yield builder.getPendingBuildRequestStatuses()
- # Optimization cheat: only get the first 75 pending builds.
- # This caps the amount of postgres db calls for really out of
- # control builders
- pending = pending[:75]
+ # Optimization cheat: only get the first 25 pending builds.
+ # This caps the amount of postgres db calls and json size for really out
+ # of control builders
+ pending = pending[:25]
pendingStates = yield defer.DeferredList(
[p.asDict_async() for p in pending])
# Not included: basedir, cachedBuilds.
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698